# Examples projects and checkers

本目录提供在lyrebird中开发插件和checker的示例工程

## plugin

提供lyrebird开发插件的示例

## checker

提供lyrebird开发检查器的示例脚本。

### 单条数据的校验

针对网络请求中的单个目标数据进行校验。

校验策略：
*  忽略无关的请求数据
*  从获得的数据集中，获取检测所需的目标数据
*  对目标数据进行校验，得到校验结果

### 多数据关系校验

针对包含多个数据的验证集合，对集合内的数据关系进行校验。

校验策略：
*  忽略无关的请求数据
*  从获得的数据集中，获取检测所需的目标数据
*  对目标数据进行校验，得到校验结果
*  更新验证集合
